@@ -1,6 +1,4 @@
-context("Test Check Functions")
-
-
+# Test Check Functions
 # Preliminary Data -------------------------------------------------------------
 pres_mat = matrix(1, nrow = 4, ncol = 3)
 
@@ -20,15 +18,15 @@ test_that("Messages show up with wrong input", {
 
   expect_silent(check_matrix(pres_mat, "site-species"))
   expect_silent(check_matrix(dist_mat, "distance"))
-  expect_silent(check_matrix(as(pres_mat, "sparseMatrix"), "site-species"))
-  expect_silent(check_matrix(as(dist_mat, "sparseMatrix"), "distance"))
+  expect_silent(check_matrix(as(pres_mat, "dgCMatrix"), "site-species"))
+  expect_silent(check_matrix(as(dist_mat, "dgCMatrix"), "distance"))
 
   expect_silent(check_bigger_dist(pres_mat, dist_mat))
   expect_silent(check_bigger_pres(pres_mat, dist_mat))
 
   expect_silent(full_matrix_checks(pres_mat, dist_mat))
-  expect_silent(full_matrix_checks(as(pres_mat, "sparseMatrix"), dist_mat))
-  expect_silent(full_matrix_checks(pres_mat, as(dist_mat, "sparseMatrix")))
+  expect_silent(full_matrix_checks(as(pres_mat, "dgCMatrix"), dist_mat))
+  expect_silent(full_matrix_checks(pres_mat, as(dist_mat, "dgCMatrix")))
 
   # Provided objects not matrices
   expect_error(
@@ -44,13 +42,13 @@ test_that("Messages show up with wrong input", {
     regexp = "Provided distance matrix is not a matrix"
   )
   expect_error(
-    check_matrix(rep(1, 2),"distance"),
+    check_matrix(rep(1, 2), "distance"),
     regexp = "Provided distance matrix is not a matrix"
   )
 
   # Bigger distance matrix
   expect_message(
-    check_bigger_dist(pres_mat[,1:2], dist_mat),
+    check_bigger_dist(pres_mat[, 1:2], dist_mat),
     regexp = paste("Distance matrix bigger than site-species matrix",
                    "Taking subset of distance matrix", sep = "\n")
   )
@@ -61,7 +59,7 @@ test_that("Messages show up with wrong input", {
     regexp = "^More species in site-species matrix than in distance.*"
   )
   expect_message(
-    check_bigger_pres(pres_mat, dist_mat[1:2,]),
+    check_bigger_pres(pres_mat, dist_mat[1:2, ]),
     regexp = "^More species in site-species matrix than in distance.*"
   )
   expect_message(
@@ -75,7 +73,7 @@ test_that("Find Common species between matrices or between df and matrix", {
   # Between matrices
   expect_equal(get_common_species(pres_mat, dist_mat), letters[1:3])
 
-  expect_equal(get_common_species(pres_mat[,1:2], dist_mat), letters[1:2])
+  expect_equal(get_common_species(pres_mat[, 1:2], dist_mat), letters[1:2])
   expect_equal(get_common_species(pres_mat, dist_mat[1:2, 1:2]), letters[1:2])
   expect_equal(get_common_species(pres_mat, dist_mat[1:2,]), letters[1:2])
   expect_equal(get_common_species(pres_mat, dist_mat[, 1:2]), letters[1:2])
@@ -86,8 +84,8 @@ test_that("Find Common species between matrices or between df and matrix", {
   # Between distance matrix and data.frame
   expect_equal(species_in_common_df(com_df, "species", dist_mat), letters[1:3])
 
-  expect_equal(species_in_common_df(com_df[1:4,], "species", dist_mat), "a")
-  expect_equal(species_in_common_df(com_df, "species", dist_mat[1:2,]),
+  expect_equal(species_in_common_df(com_df[1:4, ], "species", dist_mat), "a")
+  expect_equal(species_in_common_df(com_df, "species", dist_mat[1:2, ]),
                letters[1:2])
   expect_equal(species_in_common_df(com_df, "species", dist_mat[, 1:2]),
                letters[1:2])
@@ -137,11 +135,11 @@ test_that("Check for _stack() and _com() functions", {
 
   # Check number of species between distance matrix and community data.frame
   expect_message(
-    check_n_sp_df(com_df, "species", dist_mat[1:2,]),
+    check_n_sp_df(com_df, "species", dist_mat[1:2, ]),
     regexp = "^More species in community data.frame than in distance matrix.*"
   )
   expect_message(
-    check_n_sp_df(com_df[1:2,], "species", dist_mat),
+    check_n_sp_df(com_df[1:2, ], "species", dist_mat),
     regexp = paste0("More species in distance matrix than in community data",
                     ".frame\n", "Taking subset of distance matrix")
   )
@@ -159,8 +157,8 @@ test_that("Full checks work", {
 
   expect_error(full_matrix_checks("", dist_mat))
   expect_error(full_matrix_checks(pres_mat, ""))
-  expect_message(full_matrix_checks(pres_mat[,1:2], dist_mat))
-  expect_message(full_matrix_checks(pres_mat, dist_mat[,1:2]))
+  expect_message(full_matrix_checks(pres_mat[, 1:2], dist_mat))
+  expect_message(full_matrix_checks(pres_mat, dist_mat[, 1:2]))
 
   expect_error(full_df_checks("", "species", "site", abund = NULL, dist_mat))
   expect_error(full_df_checks(com_df, "sp", "site", abund = NULL, dist_mat))
@@ -169,7 +167,7 @@ test_that("Full checks work", {
   expect_error(full_df_checks(com_df, "species", "site", abund = NULL, ""))
   expect_error(full_df_checks(com_df, "species", "site", "species", dist_mat))
   expect_message(full_df_checks(com_df, "species", "site",
-                                dist_matrix = dist_mat[1:2,]))
-  expect_message(full_df_checks(com_df[1:2,], "species", "site",
+                                dist_matrix = dist_mat[1:2, ]))
+  expect_message(full_df_checks(com_df[1:2, ], "species", "site",
                                 dist_matrix = dist_mat))
 })
